/*
 * secfingerd
 * config.h - configurable options header file
 *
 * Copyright (c) 1999 Ni9 Technologies [x3/intrinsic]
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef __CONFIG_H
#define __CONFIG_H

#define NO_SYMLINKS   1                         /* set this to 1 if you want
                                                 * to disallow symlinks, any
                                                 * other value will turn this
                                                 * option off */
#define U_NOFINGER    ".nofinger"               /* the user's nofinger file,
                                                 * the filename will be prefixed
                                                 * with the user's home
                                                 * directory */
#define G_NOFINGER    "/usr/local/etc/secfingerd.nofinger"  /* the global
                                                             * nofinger file */
#define U_TEMPLATE    ".secfingerd.tpl"         /* the user's nofinger file,
                                                 * the filename will be prefixed
                                                 * with the user's home
                                                 * directory */
#define U_PLAN        ".plan"                   /* the user's plan file, the
                                                 * filename will be prefixed
                                                 * with the user's home
                                                 * directory */
#define U_PROJECT     ".project"                /* the user's project file, the
                                                 * filename will be prefixed
                                                 * with the user's home
                                                 * directory */
#define U_PUBKEY      ".pubkey"                 /* the user's public key file,
                                                 * the filename will be prefixed
                                                 * with the user's home
                                                 * directory */

/*
 * Errors that are sent to the client, the E_NOFINGER message is set to the
 * the same as E_NOUSER to confuse any crackers using the finger daemon to
 * gather information before an attack.  The nofinger message used before this
 * release was:
 *
 * #define E_NOFINGER    "User does not want to be fingered."
 */
#define E_INDIRECTQ   "This finger daemon does not support indirect queries."
#define E_EMPTYQ      "This finger daemon does not support empty queries."
#define E_NOUSER      "User does not exist on this machine."
#define E_NOFINGER    "User does not exist on this machine."
#define E_FILENF      "File not found."
#define E_SYMLINK     "Symbolic link detected whilst NO_SYMLINK = 1."

/*
 * These two messages are used in the logfile in the hostname field, if the
 * hostname has not been found for some reason.
 */
#define K_NOTCHOSEN   "-"
#define K_FAILURE     "Failure looking up hostname"

/*
 * Symbols used in the template files, all these are prefixed with a backslash.
 * To print a backslash use "\\".  You should not change these unless you really
 * need to as it will make the template files less portable.
 */
#define S_NAME        'u'
#define S_GECOS       'g'
#define S_DIR         'd'
#define S_SHELL       's'
#define S_PLAN        'p'
#define S_PROJECT     'j'
#define S_PUBKEY      'k'

#endif /* __CONFIG_H */
