/*
 * secfingerd
 * secfingerd.h - secure, user customizable finger daemon header file
 *
 * Copyright (c) 1999 Ni9 Technologies [x3/intrinsic]
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef __SECFINGERD_H
#define __SECFINGERD_H

#define VERSION       "0.96"

/*
 * String lengths.
 */
#define LENGTH_QUERY  255
#define LENGTH_PATH   1024
#define LENGTH_USER   1024
#define LENGTH_IP     40

/*
 * Function to display the correct program usage.
 */
void
usage(
        char *                                  /* argv[0] please */
        );

/*
 * Function to create a full path given the passwd structure (which holds the
 * user's home directory) and the filename to append to the directory.  Returns
 * the complete path.
 */
char *
build_full_path(
	struct passwd *,                        /* passwd structure */
	char *                                  /* filename */
	);

/*
 * Function to read a user name from the global nofinger file, returns 0 on
 * success and EOF when EOF is reached in the file.  This function was writen
 * to fix an overflow that existed in secfingerd release 0.92, for more
 * information read the secfingerd-0.92-1.txt file in the doc directory.
 *
 * XXX - This user name returning system will be cleaned up in the next
 *       release.
 */
int
read_user(
	FILE *,                                 /* template file handle */
	char *                                  /* pointer to user name */
	);

/*
 * Function to check if a nofinger file exists in the user's home directory,
 * if one does then the function returns -1.  If a nofinger file does not
 * exist in the user's home directory then the global nofinger file is
 * consulted, if the user name exists in the global nofinger file then -1 is
 * returned otherwise 0 is returned.
 */
int
check_for_nofinger(
	struct passwd *,                        /* user_info structure */ 
	char *                                  /* global nofinger file name */
	);

/*
 * Function to check if a template file exists in the user's home directory,
 * returns 0 if there is and -1 if there is not.
 */
int
check_for_template(
	struct passwd *                         /* user_info structure */ 
	);

/*
 * Function to check for a symbolic link, if the file is a symbolic link then
 * the function returns -1 otherwise 0 is returned.
 */
int
check_for_symlink(
	char *                                  /* file to check */
	);

/*
 * Function to dump a file, all error handling is done internaly.
 */
void
dump_file(
	struct passwd *,                        /* user_info structure */
	char *,                                 /* filename, this will be
	                                         * automaticaly prefixed with
						 * the user's home directory */
	int,                                    /* log level, see documentation
	                                         * for values */
	char *,                                 /* remote client's numerical ip
	                                         * address in string form */
	char *                                  /* remote client's ip address */
	);

/*
 * Function to dump the finger details using a custom template file, all error
 * handling is done internaly.
 */
void
dump_using_template(
	struct passwd *,                        /* user_info structure */
	char *,                                 /* template filename */
	int,                                    /* log level, see documentation
	                                         * for values */
	char *,                                 /* remote client's numerical ip
	                                         * address in string form */
	char *                                  /* remote client's ip address */
	);

/*
 * Function to dump the finger details using a default template layout, all
 * error handling is done internaly.
 */
void
dump_without_template(
	struct passwd *,                        /* user_info structure */
	int,                                    /* log level, see documentation
	                                         * for values */
	char *,                                 /* remote client's numerical ip
	                                         * address in string form */
	char *                                  /* remote client's ip address */
	);

#endif /* __SECFINGERD_H */
